@@ -30,6 +30,7 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "C",
 #'
 #' @template ssBasicParam
 #' @template ssAdvancedParam
+#' @template ssIntervals
 #' @template ssInitialParam
 #' @template ssPersistenceParam
 #' @template ssAuthor
@@ -165,7 +166,7 @@ gum <- function(y, orders=c(1,1), lags=c(1,frequency(y)), type=c("additive","mul
                 initial=c("optimal","backcasting"), ic=c("AICc","AIC","BIC","BICc"),
                 loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                 h=10, holdout=FALSE, cumulative=FALSE,
-                interval=c("none","parametric","semiparametric","nonparametric"), level=0.95,
+                interval=c("none","parametric","likelihood","semiparametric","nonparametric"), level=0.95,
                 occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
                 oesmodel="MNN",
                 bounds=c("restricted","admissible","none"),
