@@ -13,6 +13,7 @@ utils::globalVariables(c("modelDo","initialValue","lagsModelMax"));
 #'
 #' @template ssIntermittentRef
 #' @template ssInitialParam
+#' @template ssIntervals
 #' @template ssPersistenceParam
 #' @template ssAuthor
 #' @template ssKeywords
@@ -40,27 +41,6 @@ utils::globalVariables(c("modelDo","initialValue","lagsModelMax"));
 #' @param h The forecast horizon.
 #' @param holdout If \code{TRUE}, holdout sample of size \code{h} is taken from
 #' the end of the data.
-#' @param interval The type of interval to construct. This can be:
-#'
-#' \itemize{
-#' \item \code{none}, aka \code{n} - do not produce prediction
-#' interval.
-#' \item \code{parametric}, \code{p} - use state-space structure of ETS. In
-#' case of mixed models this is done using simulations, which may take longer
-#' time than for the pure additive and pure multiplicative models.
-#' \item \code{semiparametric}, \code{sp} - interval based on covariance
-#' matrix of 1 to h steps ahead errors and assumption of normal / log-normal
-#' distribution (depending on error type).
-#' \item \code{nonparametric}, \code{np} - interval based on values from a
-#' quantile regression on error matrix (see Taylor and Bunn, 1999). The model
-#' used in this process is e[j] = a j^b, where j=1,..,h.
-#' }
-#' The parameter also accepts \code{TRUE} and \code{FALSE}. The former means that
-#' parametric interval are constructed, while the latter is equivalent to
-#' \code{none}.
-#' If the forecasts of the models were combined, then the interval are combined
-#' quantile-wise (Lichtendahl et al., 2013).
-#' @param level The confidence level. Defines width of prediction interval.
 #' @param bounds What type of bounds to use in the model estimation. The first
 #' letter can be used instead of the whole word.
 #' @param silent If \code{silent="none"}, then nothing is silent, everything is
@@ -148,7 +128,7 @@ utils::globalVariables(c("modelDo","initialValue","lagsModelMax"));
 oes <- function(y, model="MNN", persistence=NULL, initial="o", initialSeason=NULL, phi=NULL,
                 occurrence=c("fixed","general","odds-ratio","inverse-odds-ratio","direct","auto","none"),
                 ic=c("AICc","AIC","BIC","BICc"), h=10, holdout=FALSE,
-                interval=c("none","parametric","semiparametric","nonparametric"), level=0.95,
+                interval=c("none","parametric","likelihood","semiparametric","nonparametric"), level=0.95,
                 bounds=c("usual","admissible","none"),
                 silent=c("all","graph","legend","output","none"),
                 xreg=NULL, xregDo=c("use","select"), initialX=NULL,
@@ -722,7 +702,12 @@ oes <- function(y, model="MNN", persistence=NULL, initial="o", initialSeason=NUL
 
             # If interal is needed, transform the error and use normal distribution
             if(interval){
-                df <- obsInSample - 1;
+                if(intervalType!="l"){
+                    df <- obsInSample - 1;
+                }
+                else{
+                    df <- obsInSample;
+                }
                 if(df>0){
                     upperquant <- qt((1+level)/2,df=df);
                     lowerquant <- qt((1-level)/2,df=df);
@@ -849,6 +834,8 @@ oes <- function(y, model="MNN", persistence=NULL, initial="o", initialSeason=NUL
             cumulative <- FALSE;
             pForecast <- rep(1, h);
             environment(ssForecaster) <- environment();
+            # This is needed for the degrees of freedom calculation
+            nParam <- length(A);
             # Call the forecaster
             ssForecaster(ParentEnvironment=environment());
             # Revert to the original occurrence
